@@ -19,7 +19,7 @@ See http://docs.openstack.org/developer/oslo.i18n/usage.html
 import oslo_i18n
 
 
-_translators = oslo_i18n.TranslatorFactory(domain='oslo.cache')
+_translators = oslo_i18n.TranslatorFactory(domain='oslo_cache')
 
 # The primary translation function using the well-known name "_"
 _ = _translators.primary
